.. _tutorials:

Tutorials
=========

Welcome to the grogupy tutorials! Here, you will find a series of step-by-step 
guides designed to help you get started with grogupy and explore its advanced 
features.

.. toctree::
   :maxdepth: 2

   io_formats
   magnetic_entity
   memory_management
   convergence_with_high_throughput
   command_line_usage
   fix_gpu_linking
